@@ -26,6 +26,5 @@ class Job:
     created_at: str
     updated_at: str
     errors: List[str]
-    device_status: str = None
-    result: str = None
+    result: Dict = None
     variables: Dict = None
